@@ -36,3 +36,26 @@ class HairType(AvatarPart):
     STRAIGHT_1 = 'straight_1'
     STRAIGHT_2 = 'straight_2'
     STRAIGHT_STRAND = 'straight_strand'
+    ASTRONAUT = 'astronout'
+    BRAIDS = 'braids'
+    BRIDE = 'bride'
+    BUZZCUT = 'buzzcut'
+    CORNROWS = 'cornrows'
+    CURLY_2 = 'curly_2'
+    DREADLOCKS = 'dreadlocks'
+    EINSTEIN_HAIR = 'einstein_hair'
+    ELVIS = 'elvis'
+    EVIL_SPIKE = 'evil_spike'
+    HALF_SHAVED = 'half_shaved'
+    HAT = 'hat'
+    LONG_HAIR_CURLY = 'long_hair_curly'
+    LOOSE_HAIR = 'loose_hair'
+    MOHAWK = 'mohawk'
+    MOWGLI = 'mowgli'
+    PIXIE = 'pixie'
+    POMPADOUR = 'pompadour'
+    QUIFF = 'quiff'
+    TWIST_LONG_HAIR = 'twist_long_hair'
+    TWIST_LONG_HAIR_2 = 'twist_long_hair_2'
+    WICK = 'wick'
+    WILD = 'wild'
